from datetime import datetime, timedelta

from notecoin.huobi.history.core import load_daily_all
from notedrive.lanzou import LanZouCloud

downer = LanZouCloud()
downer.ignore_limits()
downer.login_by_cookie()

start_date = datetime(2021, 5, 3)
end_date = datetime(2021, 5, 31)
duration = end_date - start_date
for i in range(duration.days + 1):
    day = end_date - timedelta(days=i)
    file_path = load_daily_all(period='1min', date=day)
    downer.upload_file(file_path, folder_id='3359096')



from datetime import *

MONTHS = list(range(1, 13))

SPOT_START_DATE = datetime(2017, 10, 27)
FUTURE_START_DATE = datetime(2018, 11, 10)
SWAP_START_DATE = datetime(2020, 3, 25)
LINEARSWAP_START_DATE = datetime(2020, 10, 21)
OPTION_START_DATE = datetime(2020, 9, 1)

END_DATE = datetime.now()

ALL_PERIODS = ['1min', '5min', '15min', '30min', '60min', '4hour', '1day']
